# Generated by Django 2.1.2 on 2018-12-11 16:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_saas_email', '0003_auto_20181016_1827'),
    ]

    operations = [
        migrations.AddField(
            model_name='mail',
            name='cc_address',
            field=models.EmailField(blank=True, help_text="The 'cc' field of the email", max_length=254, null=True, verbose_name='CC email address'),
        ),
    ]
