# Generated by Django 2.1.2 on 2019-01-21 12:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_saas_email', '0004_mail_cc_address'),
    ]

    operations = [
        migrations.AddField(
            model_name='mail',
            name='bcc_address',
            field=models.EmailField(blank=True, help_text="The 'bcc' field of the email", max_length=254, null=True, verbose_name='BCC email address'),
        ),
    ]
